@@ -14,6 +14,7 @@ __all__ = [
     "make_unit",
     "make_compound_dimension",
     "make_compound_unit",
+    "si_unit",
     "SIUNITX_NEW",
     "SIUNITX_OLD",
 ]
@@ -52,8 +53,9 @@ def make_unit(*, name: str, dimension: 'DimensionBase', scale: Scale, abbrev: st
     example a particular length like 8 meters. Instances of a unit class are
     called "measurements" within this documentation. Instances are immutable;
     any interactions with the public API will not change the object, anything
-    that appears like it (for instance rounding with ``.sig_figs``) instead
-    constructs and returns a copy.
+    that appears like it (for instance rounding with
+    :meth:`sig_figs <pyunitx.length.meters.sig_figs>`) instead constructs and
+    returns a copy.
 
     :param name: The name of the new unit, like "meters". Should be in its
         plural form.
@@ -72,13 +74,18 @@ def make_unit(*, name: str, dimension: 'DimensionBase', scale: Scale, abbrev: st
     def new(cls, value: Scale):
         """Create a new measurement using this unit.
 
-        Instances are flyweights; two invocations of meters(1) will return the
-        same object.
+        Instances are flyweights; two invocations of ``meters(1)`` will return
+        the same object.
+
+        :param value: The numerical value of the measurement, in any form that
+            :external:py:class:`decimal.Decimal` can accept.
+        :return: The newly created measurement, or the cached version.
         """
-        if value not in cls.instances:
-            cls.instances[value] = super(type, cls).__new__(cls)
-        instance = cls.instances[value]
-        instance.value = Decimal(value)
+        v = Decimal(value)
+        if v not in cls.instances:
+            cls.instances[v] = super(type, cls).__new__(cls)
+        instance = cls.instances[v]
+        instance.value = v
         return instance
 
     def add(self, other: UnitInterface) -> UnitInterface:
@@ -86,9 +93,10 @@ def make_unit(*, name: str, dimension: 'DimensionBase', scale: Scale, abbrev: st
 
         Checks compatibility rather than type for determining "same unit". For
         example, a calculation that outputs the dynamically created unit
-        kg*m*s^-2 is equivalent to a defined expression using newtons.
+        ``kg*m*s^-2`` is equivalent to a defined expression using newtons.
 
         :param other: Another measurement, with the same units
+        :return: A measurement with the values of the two added
         """
         if type(other).composition != type(self).composition:
             raise OperationError("add", type(self), type(other))
@@ -99,9 +107,10 @@ def make_unit(*, name: str, dimension: 'DimensionBase', scale: Scale, abbrev: st
 
         Checks compatibility rather than type for determining "same unit". For
         example, a calculation that outputs the dynamically created unit
-        kg*m*s^-2 is equivalent to a defined expression using newtons.
+        ``kg*m*s^-2`` is equivalent to a defined expression using newtons.
 
         :param other: Another measurement, with the same units
+        :return: A measurement with the values of the two subtracted
         """
         if type(other).composition != type(self).composition:
             raise OperationError("subtract", type(self), type(other))
@@ -112,7 +121,7 @@ def make_unit(*, name: str, dimension: 'DimensionBase', scale: Scale, abbrev: st
 
         Checks compatibility rather than type for determining "same unit". For
         example, a calculation that outputs the dynamically created unit
-        kg*m*s^-2 is equivalent to a defined expression using newtons.
+        ``kg*m*s^-2`` is equivalent to a defined expression using newtons.
         """
         if self is other:
             return True
@@ -143,12 +152,21 @@ def make_unit(*, name: str, dimension: 'DimensionBase', scale: Scale, abbrev: st
         return a == b
 
     def multiply(self, other: Union[UnitInterface, int, float, Decimal]) -> UnitInterface:
-        """Multiply two measurements. Produces a new compound unit for the result.
+        """Multiply two measurements.
 
         If the two quantities completely cancel (like a frequency times a
         duration), the result will be returned as a plain number.
 
-        :param other: Another measurement, with any units.
+        Otherwise, produce the correct unit by combining the units of the two
+        multiplicands. If the result has two base units that measure the same
+        dimension but are not the same (say you're trying to multiply ``ft/s`` by
+        ``m^2``, ``ft*m^2`` would be in the result) a TypeError will be thrown.
+        Instead you should convert one of the measurements to be compatible with
+        the other before multiplying. In the example, that could be converting the
+        ``ft/s`` to ``m/s``.
+
+        :param other: Another measurement, with any units including none.
+        :raises TypeError: If base units are incompatible.
         :return: The result of the calculation, with the compound units.
         """
         if isinstance(other, (int, float, Decimal)):
@@ -164,9 +182,23 @@ def make_unit(*, name: str, dimension: 'DimensionBase', scale: Scale, abbrev: st
         return result_unit(result_value)
 
     def divide(self, other: Union[UnitInterface, int, float, Decimal]) -> UnitInterface:
-        """Multiply two measurements. Produces a new compound unit for the result.
+        """Divide two measurements.
 
-        :param other: Another measurement, with any units.
+        If the two quantities completely cancel (like the derivation of radians
+        dividing length by length), the result will be returned as a plain
+        number.
+
+        Otherwise, produce the correct unit by combining the units of the two
+        divisors. If the result has two base units that measure the same
+        dimension but are not the same (say you're trying to divide ``ft/s`` by
+        ``m^2``, ``ft/m^2`` would be in the result) a TypeError will be thrown.
+        Instead you should convert one of the measurements to be compatible with
+        the other before multiplying. In the example, that could be converting the
+        ``ft/s`` to ``m/s``.
+
+        :param other: Another measurement, with any units including none.
+        :raises TypeError: If base units are incompatible.
+        :return: The result of the division, with correct units.
         """
         if isinstance(other, (int, float, Decimal)):
             return type(self)(self.value / Decimal(other))
@@ -180,6 +212,11 @@ def make_unit(*, name: str, dimension: 'DimensionBase', scale: Scale, abbrev: st
         )
         return result_unit(result_value)
 
+    # rdivide can be much simpler because dividing two units will be handled by main divide
+    def rdivide(self, other: Union[int, float, Decimal]) -> UnitInterface:
+        result_unit = type(self ** -1)
+        return result_unit(Decimal(other) / self.value)
+
     def exponent(self, other: Scale) -> UnitInterface:
         """Raise this measurement to a power such that the result has no
         non-integer exponents.
@@ -195,21 +232,65 @@ def make_unit(*, name: str, dimension: 'DimensionBase', scale: Scale, abbrev: st
         :raises ValueError: If the resulting unit has fractional exponents.
         :return: A measurement with the value and units raised to the power.
         """
-        result_composition = self.composition ** other
-        result_value = self.value ** Decimal(other)
+        v = Decimal(other)
+        result_composition = self.composition ** v
+        result_value = self.value ** v
         result_unit = make_compound_unit(
-            scale=self.scale ** Decimal(other),
+            scale=self.scale ** v,
             exponents=result_composition.to_pairs()
         )
         return result_unit(result_value)
 
+    def less(self, other: UnitInterface):
+        """Check if this measurement is less than another.
+
+        :param other: The measurement to compare to.
+        :raises TypeError: If the two arguments are different units and can
+            therefore not be compared.
+        :return: Whether the other measurement is less than this one.
+        """
+        if type(other).composition != type(self).composition:
+            raise TypeError(f"{self.abbreviation} and {other.abbreviation} cannot be compared")
+        return self.value * self.scale < other.value * other.scale
+
+    def lesseq(self, other: UnitInterface):
+        """Check if this measurement is less than or equal to another.
+
+        :param other: The measurement to compare to.
+        :raises TypeError: If the two arguments are different units and can
+            therefore not be compared.
+        :return: Whether the other measurement is less than this one.
+        """
+        return self < other or self == other
+
+    def absolute(self):
+        """Get the absolute value of this measurement.
+
+        :return: A copy of this measurement as an absolute value.
+        """
+        return type(self)(abs(self.value))
+
+    def neg(self):
+        """Get the negative of this measurement.
+
+        :return: A copy of this measurement with sign flipped.
+        """
+        return type(self)(-self.value)
+
+    def pos(self):
+        """No-op, return self.
+
+        This is unlike any other math operation since it doesn't make a copy.
+        """
+        return self
+
     def is_dimension(self, dim: DimensionBase):
         """Check if this unit is of the given dimension.
 
         Most useful for checking whether two measurements can be reasonably
         compared with ``.equivalent_to`` or converted into the other.
 
-        :param dim: The dimension to
+        :param dim: The dimension to check against.
         :return: Whether this unit is of the given dimension.
         """
         try:
@@ -293,28 +374,42 @@ def make_unit(*, name: str, dimension: 'DimensionBase', scale: Scale, abbrev: st
     # @formatter:off
     # noinspection PyTypeChecker
     unit: Type[UnitInterface] = type(name, (object,), {
+        # Initializers
         "__new__": new,
+        # Math
         "__add__": add,
         "__radd__": add,
         "__sub__": subtract,
-        "__eq__": equal,
+        "__rsub__": subtract,
+        "__abs__": absolute,
+        "__pos__": pos,
+        "__neg__": neg,
         "__mul__": multiply,
         "__rmul__": multiply,
         "__truediv__": divide,
-        "__rtruediv__": divide,
+        "__rtruediv__": rdivide,
+        "__pow__": exponent,
+        # Get special conversion functions
         "__getattr__": getattribute,
+        # Comparisons; python can figure out the rest from this minimal set
+        "__eq__": equal,
+        "__lt__": less,
+        "__le__": lesseq,
+        # Stringifiers
         "__str__": tostring,
         "__repr__": tostring,
-        "__pow__": exponent,
+        # Special class variables
         "__name__": name,
         "__doc__": textwrap.dedent(doc),
+        # Class variables
         "is_dimension": is_dimension,
+        "abbreviation": abbrev,
         "scale": Decimal(scale),
         "instances": {},
         "dimension": dimension,
+        # Methods
         "equivalent_to": equivalent,
         "sig_figs": sig_figs,
-        "abbreviation": abbrev,
         "to_latex": to_latex,
     })
     # @formatter:on
@@ -351,7 +446,7 @@ def make_compound_dimension(exponents: Exponents, name: str = None) -> 'Dimensio
 
 
 def make_compound_unit(*, scale: Scale, exponents: Exponents, name: str = None, abbrev=None,
-                       doc=""):
+                       doc="") -> Type['UnitInterface']:
     """A unit composed of other units.
 
     :param scale: How many of the base unit one of this unit is equivalent to.
@@ -396,6 +491,67 @@ def make_compound_unit(*, scale: Scale, exponents: Exponents, name: str = None,
     return unit
 
 
+def si_unit(*, base_unit: Type['UnitInterface'], short_doc="", skip=()) \
+        -> Dict[str, Type['UnitInterface']]:
+    """Create the full range of SI prefixes on a unit.
+
+    :param base_unit: The unit to which prefixes can be applied.
+    :param short_doc: A short documentation snippet to apply to every created
+        unit, just so that they show up in sphinx documentation.
+    :param skip: If you've already created one of the units (I did this with
+        kilograms since prefixes apply to grams), list the prefix here so it
+        doesn't get overwritten.
+    :return: A dictionary between the name of the unit and the unit class.
+    """
+    prefixes = [
+        ["yotta", "Y", "1e24"],
+        ["zetta", "Z", "1e21"],
+        ["exa", "E", "1e18"],
+        ["peta", "P", "1e15"],
+        ["tera", "T", "1e12"],
+        ["giga", "G", "1e9"],
+        ["mega", "M", "1e6"],
+        ["kilo", "k", "1e3"],
+        ["hecto", "h", "1e2"],
+        ["deka", "da", "1e1"],
+        ["deci", "d", "1e-1"],
+        ["centi", "c", "1e-2"],
+        ["milli", "m", "1e-3"],
+        ["micro", "μ", "1e-6"],
+        ["nano", "n", "1e-9"],
+        ["pico", "p", "1e-12"],
+        ["femto", "f", "1e-15"],
+        ["atto", "a", "1e-18"],
+        ["zepto", "z", "1e-21"],
+        ["yocto", "y", "1e-24"],
+    ]
+    generated = {}
+    for prefix, short, scale in prefixes:
+        if prefix in skip:
+            continue
+        new_scale = Decimal(scale) * base_unit.scale
+        new_name = prefix + base_unit.__name__
+        new_abbrev = short + base_unit.abbreviation
+        if base_unit.composition == Compound(Multiset({base_unit: 1})):
+            new_unit = make_unit(
+                name=new_name,
+                abbrev=new_abbrev,
+                scale=new_scale,
+                dimension=base_unit.dimension,
+                doc=short_doc,
+            )
+        else:
+            new_unit = make_compound_unit(
+                name=new_name,
+                abbrev=new_abbrev,
+                scale=new_scale,
+                exponents=base_unit.composition.to_pairs(),
+                doc=short_doc,
+            )
+        generated[new_name] = new_unit
+    return generated
+
+
 def _exponent_name(unit: type, exponent: int) -> str:
     value_names = {
         1: "",
@@ -447,7 +603,7 @@ def _sort(d: Union[Exponents, Iterator[Pair]]) -> Pairs:
     return tuple(sorted(pairs, key=lambda p: (-p[1], p[0].__name__)))
 
 
-def _access_unit_cache(c: 'Compound', scale) -> Optional['UnitInterface']:
+def _access_unit_cache(c: 'Compound', scale) -> Optional[Type['UnitInterface']]:
     remap = {(_sort(_dedupe(unit.composition.to_pairs())), unit.scale): unit
              for name, unit in _EXTANT_UNITS.items()}
     key = (_sort(_dedupe(c.to_pairs())), scale)
