@@ -1,14 +1,10 @@
-from pyunitx._api import make_compound_dimension, make_compound_unit
-from pyunitx.length import Length, meters
+from pyunitx._api import make_compound_dimension, make_compound_unit, si_unit
+from pyunitx.force import pounds
+from pyunitx.length import Length, meters, feet
 from pyunitx.mass import Mass, kilograms
 from pyunitx.time import seconds, Time
 
-__all__ = [
-    "Energy",
-    "joules",
-    "kilojoule",
-    "calorie",
-]
+
 
 Energy = make_compound_dimension({Mass: 1, Length: 2, Time: -2}, "Energy")
 
@@ -22,16 +18,10 @@ joules = make_compound_unit(
     work done on an object by pushing it with a 1 N force for 1 m. 
     """
 )
-kilojoule = make_compound_unit(
-    name="kilojoule",
-    scale=1000,
-    exponents=joules.composition.to_pairs(),
-    abbrev="kJ",
-    doc="""\
-    Since the joule is a pretty small amount of energy, kilojoules see common 
-    use.
-    """
-)
+
+generated = si_unit(base_unit=joules, short_doc="The :class:`joule` is the SI base unit.")
+globals().update(generated)
+
 calorie = make_compound_unit(
     name="calorie",
     scale="4.184",
@@ -43,3 +33,20 @@ calorie = make_compound_unit(
     kilogram in the calculation instead.
     """
 )
+btu = make_compound_unit(
+    name="btu",
+    abbrev="btu",
+    scale="1.05435e3",
+    exponents={feet: 1, pounds: 1},
+    doc="""\
+    There are many different possible definitions of the British Thermal Unit, 
+    this is the thermochemical definition.
+    """
+)
+
+__all__ = [
+              "Energy",
+              "joules",
+              "calorie",
+              "btu",
+          ] + list(generated.keys())
