@@ -1,4 +1,4 @@
-from pyunitx._api import make_compound_unit, make_compound_dimension
+from pyunitx._api import make_compound_unit, make_compound_dimension, si_unit
 from pyunitx.charge import Charge, coulombs
 from pyunitx.energy import Energy, joules
 
@@ -13,3 +13,11 @@ volts = make_compound_unit(
     Volts are the only real unit of electrical potential energy.
     """
 )
+
+generated = si_unit(base_unit=volts, short_doc="")
+globals().update(generated)
+
+__all__ = [
+              "Potential",
+              "volts",
+          ] + list(generated.keys())
